|PyPI| |Docs|

.. |PyPI| image:: https://img.shields.io/pypi/v/scanpy.svg
   :target: https://pypi.org/project/scRFE/
.. |Docs| image:: https://readthedocs.com/projects/icb-scanpy/badge/?version=latest
   :target: https://scRFE.readthedocs.io/en/latest/introduction.html



Introduction
================
scRFE (single-cell identity definition using random forest modelling and recursive feature elimination) is a python package that uses a one vs all random forest classifier with recursive feature elimination to identify the set of genes necessary and sufficient to describe the different features of your single-cell RNA sequencing data.

scRFE is still under development. A preprint of our scRFE paper will be available soon on bioRxiv. All datasets used with scRFE are available on Figshare.

scRFE is produced by CZ Biohub.

For questions, please contact Madeline Park at madeline.park@czbiohub.org.
